uniform sampler2D BumpTex;
uniform sampler2D DecalTex;

varying	vec3 g_lightVec;
varying	vec3 g_viewVec;
 

void main() 
{
	vec3 lightVec = normalize(g_lightVec);
	vec3 viewVec = normalize(g_viewVec);

	// get texture and bumb coordinates
	vec3 tcoord = gl_TexCoord[0].xyz;
	vec4 bumbcoord = texture2D(BumpTex, tcoord.xy);

	// decompress color (auf [0,1])
	vec3 BumpNorm = normalize(bumbcoord.rgb * 2.0 - 1.0);

	vec4 baseCol = texture2D(DecalTex,  tcoord.xy);

	float distSqr = dot(lightVec, lightVec);
	float att = clamp(1.0 - 0.2 * sqrt(distSqr), 0.0, 1.0); //http://www.ozone3d.net
		
	float diffuseLambert = max(dot(lightVec, BumpNorm), 0.0);
	float specular = pow(clamp(dot(reflect(viewVec, BumpNorm), lightVec * inversesqrt(distSqr)), 0.0, 1.0), 4.0);
	//vec4  specularCorrection = vec4(0.25,0.25,0.25,0.25);	
	vec4  specularCorrection = vec4(1.0,1.0,1.0,1.0);	
	

	 //calculate fog attenuation
   float fogAtten = 1.0 - (gl_Fog.end - gl_FogFragCoord) * gl_Fog.scale;
   fogAtten = clamp(fogAtten, 0.0, 1.0);


	// final color calculation
	gl_FragColor = mix((baseCol*0.3 + diffuseLambert*baseCol + specular*0.3)*att, gl_Fog.color, fogAtten); // (baseCol*0.3 + diffuseLambert*baseCol + specular*0.3)*att;

 }
/*
void main (void)
{
    vec3 litColor;
    vec2 c = BumpDensity * gl_TexCoord[0].st;
    vec2 p = fract(c) - vec2(0.5);

    float d, f;
    d = p.x * p.x + p.y * p.y;
    f = 1.0 / sqrt(d + 1.0);

    if (d >= BumpSize)
        { p = vec2(0.0); f = 1.0; }

    vec3 normDelta = vec3(p.x, p.y, 1.0) * f;
    litColor = SurfaceColor * max(dot(normDelta, LightDir), 0.0);
    vec3 reflectDir = reflect(LightDir, normDelta);
    
    float spec = max(dot(EyeDir, reflectDir), 0.0);
    spec *= SpecularFactor;
    litColor = min(litColor + spec, vec3(1.0));

    gl_FragColor = vec4(litColor, 1.0);
}*/