package gui;

import javax.swing.*;
import java.awt.Color;
import java.awt.Dimension;

public class CGHeaderFooterFrm extends JFrame {

	private static final long serialVersionUID = 000000l;
	
	// GUI Elements
	private JPanel contentPane;
	private JTextArea infoArea;
	private JTextArea headerArea, footerArea;
	private String header, footer;
	
	public CGHeaderFooterFrm(){
		super( "Set Header and Footer" );
		initialize();
	}
	
	private void initialize(){
		// Default header
		header = "<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n" +
			    "<CrazyWheels>\n" +
			    "\t<MetaData />\n" +
			    "\t<Lightdata ambientX=\"0.7\" ambientY=\"0.7\" ambientZ=\"0.7\" ambientW=\"0.7\" specularX=\"0.5\" specularY=\"0.5\" specularZ=\"0.5\" specularW=\"1\" diffuseX=\"1\" diffuseY=\"1\" diffuseZ=\"1\" diffuseW=\"1\" lightposX=\"100\" lightposY=\"100\" lightposZ=\"100\" lightdirX=\"0.33\" lightdirY=\"-0.33\" lightdirZ=\"0.33\" />\n" +
			    "\t<Shaders>\n" +
			    "\t\t<Shader name=\"watershader\" vertshader=\"data/water/bump.vert\" fragshader=\"data/water/bump.frag\" />\n" +
			    "\t</Shaders>\n" +
			    "\t<Water>\n" +
			    "\t\t<Init name=\"water\" normalmap=\"data/water/w_normalmap.bmp\" distortionmap=\"data/water/w_distortion1.bmp\" waterheight=\"-80\" transparent=\"true\" wateruv=\"35\" waterflow=\"0.015\" shader=\"watershader\" colorR=\"0.1\" colorG=\"0.2\" colorB=\"0.1\" colorA=\"1\" />\n" +
			    "\t</Water>\n" +
			    "\t<Terrain>\n" +
			    "\t\t<Init name=\"Terrain\" heightmap=\"data/level/level1/img/heightmap.bmp\" originX=\"0\" originY=\"-100\" originZ=\"0\" dimensionX=\"1000\" dimensionY=\"10\" dimensionZ=\"1000\" density=\"0.4\" fogdepth=\"50.0\" shader=\"bumpshader\" />\n" +
			    "\t</Terrain>\n" +
			    "\t<SkyBox>\n" +
			    "\t\t<Init name=\"Skybox\" centerX=\"500\" centerY=\"0\" centerZ=\"500\" width=\"1000\" height=\"500\" length=\"1000\" frontTex=\"data/level/level1/img/vorne.tga\" backTex=\"data/level/level1/img/hinten.tga\" upTex=\"data/level/level1/img/oben.tga\" downTex=\"data/level/level1/img/oben.tga\" leftTex=\"data/level/level1/img/links.tga\" rightTex=\"data/level/level1/img/rechts.tga\" />\n" +
			    "\t</SkyBox>\n";
		// Default footer
		footer = "\t<!-- Introanimation-->\n" +
			    "\t<FlyIn>\n" +
			    "\t\t<FlyInPoint posX=\"256.044312\" posY=\"-45.200184\" posZ=\"438.603699\" dirX=\"0.069447\" dirY=\"0.000000\" dirZ=\"0.997586\" time=\"2.0\"/>\n" +
			    "\t\t<FlyInPoint posX=\"251.204437\" posY=\"-70.694839\" posZ=\"515.228699\" dirX=\"0.000000\" dirY=\"0.000000\" dirZ=\"1.000000\" time=\"2.0\"/>\n" +
			    "\t</FlyIn>\n" +
			    "\t<Sounds bg=\"data/media/09-t.a.t.u_and_clawfinger-my_skuchali_(bonus_track).mp3\" countdown=\"data/media/peep.wav\"/>\n" +
			    "\t<Other countdown1=\"data/level/level1/img/countdown_3.tga\" countdown2=\"data/level/level1/img/countdown_2.tga\" countdown3=\"data/level/level1/img/countdown_1.tga\" halloffame=\"data/level/level1/halloffame.xml\" />\n" +
			    "\t<MiniMap location=\"data/tertex_small.tga\" />\n" +
			    "</CrazyWheels>\n";
		this.setContentPane(getMyContentPane());
		this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE );
		this.setBounds( 10, 10, 510, 700 );
	}
	
	private JPanel getMyContentPane() {
		if (contentPane == null) {
			contentPane = new JPanel();
			contentPane.setOpaque(true);
			contentPane.add(getInfoArea());

	        JScrollPane areaScrollPane = new JScrollPane(getHeaderArea());
	        areaScrollPane.setPreferredSize(new Dimension(490, 280));
	        areaScrollPane.setBorder(
	            BorderFactory.createCompoundBorder(
	                BorderFactory.createCompoundBorder(
	                                BorderFactory.createTitledBorder("Header"),
	                                BorderFactory.createEmptyBorder(5,5,5,5)),
	                areaScrollPane.getBorder()));
			contentPane.add(areaScrollPane);
			
	        JScrollPane areaScrollPane2 = new JScrollPane(getFooterArea());
	        areaScrollPane2.setPreferredSize(new Dimension(490, 280));
	        areaScrollPane2.setBorder(
	            BorderFactory.createCompoundBorder(
	                BorderFactory.createCompoundBorder(
	                                BorderFactory.createTitledBorder("Footer"),
	                                BorderFactory.createEmptyBorder(5,5,5,5)),
	                areaScrollPane2.getBorder()));
			contentPane.add(areaScrollPane2);
		}
		return contentPane;
	}
	
	private JTextArea getInfoArea() {
		if (infoArea == null) {
			infoArea = new JTextArea();
			String s = "You can set a default header and footer here that will be written before and after the generated XML tags when creating the output file.";
			infoArea.setText(s);
			infoArea.setLineWrap(true);
			infoArea.setWrapStyleWord(true);
			infoArea.setEditable(false);
			infoArea.setFocusable(false);
			infoArea.setSize(490,5);
			infoArea.setBackground(this.getBackground());
		}
		return infoArea;
	}
	
	private JTextArea getHeaderArea() {
		if (headerArea == null) {
			headerArea = new JTextArea();
			headerArea.setText(header);
			headerArea.setSize(490,280);
			headerArea.setPreferredSize(new Dimension(2500,500));
			headerArea.setEditable(true);
			headerArea.setBackground(Color.WHITE);
		}
		return headerArea;
	}
	
	private JTextArea getFooterArea() {
		if (footerArea == null) {
			footerArea = new JTextArea();
			footerArea.setText(footer);
			footerArea.setSize(490,280);
			footerArea.setPreferredSize(new Dimension(2500,500));
			footerArea.setEditable(true);
			footerArea.setBackground(Color.WHITE);
		}
		return footerArea;
	}
	
	public String getHeader(){
		header = headerArea.getText();
		return header;
	}
	
	public String getFooter(){
		header = footerArea.getText();
		return footer;
	}
}
