package gui;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Toolkit;
import java.awt.event.*;
import java.awt.Color;
import java.io.File;
import java.util.Vector;
import java.util.Enumeration;
import javax.swing.JComponent;

import objects.*;

class CGPaintComponent extends JComponent implements MouseListener,MouseMotionListener {
	private static final long serialVersionUID = 000000l;
	private Image image;
	private CGAddedObject currentObject;
	private Color selectedColor = new Color(255,255,255);
	private Vector addedObjects	= new Vector();	// Vector holding the already added Objects
	
	// the paint method of this object
	protected void paintComponent( Graphics g ) {
		if ( image != null ){
			g.drawImage( image, 0, 0, this );
			// draw added objects
			for (Enumeration en = addedObjects.elements(); en.hasMoreElements(); ){
				CGAddedObject ao = ((CGAddedObject)(en.nextElement()));
				g.setColor(ao.getColor());
				g.fillPolygon(ao.getPolygon());
			}
			
			// draw info to current object
			if (currentObject != null){
				g.setColor(new Color(0,0,0,90));
				g.fillRect(290,4,350,20+3*16);
				g.setColor(selectedColor);
				g.drawString("Current Object: " + currentObject.getName(), 300,20);
				g.setColor(new Color(200,200,200));
				g.drawString("Position (x/z): " + currentObject.getPosition().x + "/" + currentObject.getPosition().y, 300,20+16);
				// funkt irgendwie nicht so richtig :(
				g.drawString("Position y: " + currentObject.getYPosition(), 300,20+2*16);
				g.drawString("Rotation angle about y axis: " + currentObject.getAngle(), 300,20+3*16);
			}
		}
	}

	// return the preferred size, necessary due to scroll panel reasons
	public Dimension getPreferredSize() {
		 if (image == null) {
			 return new Dimension(300, 300);
	     } else {
	     	return new Dimension(1024,1024);
	    	//return super.getPreferredSize();
	     }
	}
	
	// Set tha background image (i.e. the map)
	public void setImage( File file ) {
		image = Toolkit.getDefaultToolkit().getImage( file.getAbsolutePath() );
		if ( image != null ){
			repaint();
		}
	}
	
	// Method to add an Object
	public void addObject(CGAddedObject ao){
		// only add objects if an image has already been set
		if (image != null){
			addedObjects.add(ao);
			if (currentObject != null) currentObject.resetColor();
			currentObject = (CGAddedObject)addedObjects.lastElement();
			currentObject.setColor(selectedColor);
			repaint();
		}
	}
	
	// Method that returns the current Object
	public CGAddedObject getCurrentObject(){
		return currentObject;
	}
	
	// Method that returns the vector of objects
	public Vector getObjectVector(){
		return addedObjects;
	}

	// Method that handles the mouse interaction
	public void mouseClicked(MouseEvent e) {
		int x = e.getX();
		int y = e.getY();
		// Place an object by a rigth click
		if (e.getModifiers() == 4 && currentObject != null){
			currentObject.setPosition((float)x/1024,(float)y/1024);
			repaint();
		}
		// Select & unselect an object
		else{
			if (currentObject != null){
				currentObject.resetColor();
				currentObject = null;
				repaint();
			}
			for (Enumeration en = addedObjects.elements(); en.hasMoreElements(); ){
				CGAddedObject temp = ((CGAddedObject)(en.nextElement()));
				if( temp.getPolygon().contains(x,y)){
					if (currentObject != null) currentObject.resetColor(); 
					currentObject = temp;
					currentObject.setColor(selectedColor);
					repaint();
				}
			}
		}
	}

	public void mousePressed(MouseEvent e)  {	/* do nothing */	}

	public void mouseReleased(MouseEvent e) {	/* do nothing */	}

	public void mouseEntered(MouseEvent e)  {	/* do nothing */	}

	public void mouseExited(MouseEvent e)   {	/* do nothing */	}
	
	public void mouseDragged(MouseEvent e)  {	/* do nothing */	}

	public void mouseMoved(MouseEvent e)    {	/* do nothing */	}
}
