package objects;

import util.*;
import java.awt.*;
import gui.*;

/* Class that holds information about an added object.
 * Everything needed to create the XML File entry on a
 * particular Object should be maintained in this class
 */

public class CGAddedObject {
	// Data of this object
	// private static int id;
	private float widthX, widthZ;
	private float posX, posZ;
	private String name;		// Name of this object
	private float angleY;		// The anglethis object is rotated (0 <= angleY <= 360)
	private Color col;			// The color this object will be painted in
	private Color colBU;		// A backup of the color
	private String[] attributes;
	
	// Constructor
	public CGAddedObject (float wX, float wZ, String n, Color c, String[] a){
		widthX = wX;
		widthZ = wZ;
		name = n;
		col = c;
		colBU = c;
		attributes = a;
		// Position and angle values are initialized with default values and obtained
		// later via user interaction in the GUI.
		posX = 0.01f+wX/2;
		posZ = 0.01f+wZ/2;
		angleY = 0;
	}
	
	public CGAddedObject (float wX, float wZ, String n, Color c, Color cBU, float pX, float pZ, float an, String[] a){
		widthX = wX;
		widthZ = wZ;
		name = n;
		col = c;
		colBU = cBU;
		attributes = a;
		posX = pX;
		posZ = pZ;
		angleY = an;
	}

	// Method that returns the Y-Position (height in terrain) according to
	// the current position (obtained via the heightmap/buffer).
	public float getYPosition(){
		float yP = 0;
		CGFloatBuffer buf = CGMainFrm.getBuffer();
		if (buf != null) yP = buf.getRed((int)(posX*1024.0f),(int)(posZ*1024.0f));
		return yP;
	}

	// Method that returns the attributes of this object
	// attribute = info that is not needed within the leveleditor but written 
	// to the output file
	public String[] getAttributes(){
		return attributes;
	}
	
	// Method to set the position directly
	public void setPosition (float pX, float pZ){
		posX = pX;
		posZ = pZ;
	}
	
	// Method to rotate the object around the y axis
	public void rotateY (){
		angleY--;
		if(angleY==-1) angleY = 359;
	}
	
	// Method to rotate the object around the y axis with specified angle
	public void rotateY (float a){
		angleY -= a;
		if(angleY<=0) angleY = angleY%360; // RICHTIG SO?
	}
	
	// Method to rotate the object around the y axis counter clock wise
	public void rotateYcc (){
		angleY++;
		if(angleY==360) angleY = 0;
	}
	
	// Method to rotate the object around the y axis counter clock wise with specified angle
	public void rotateYcc (float a){
		angleY += a;
		if(angleY>=360) angleY = angleY%360;
	}
	
	// Method to move the Object along the positive x axis
	public void moveRight (){
		posX += 0.001;
	}
	
	// Method to move the Object along the negative x axis
	public void moveLeft (){
		posX -= 0.001;
	}
	
	// Method to move the Object along the positive x axis
	public void moveUp (){
		posZ += 0.001;
	}
	
	// Method to move the Object along the negative x axis
	public void moveDown (){
		posZ -= 0.001;
	}
	
	// Method to reset the angle
	public void resetAngle (){
		angleY = 0;
	}
	
	// Method that returns the color of this object
	public Color getColor(){
		return col;
	}
	
	// Method that returns the color of this object
	public Color getBUColor(){
		return colBU;
	}
	
	// Method that sets the color of this object
	public void setColor(Color c){
		col = c;
	}
	
	// Method that resets the color of this object
	public void resetColor(){
		col = colBU;
	}
	
	// Method to return the position of the Object
	public Point getPosition(){
		return new Point((int)(posX*CGMainFrm.getFactor()),(int)(posZ*CGMainFrm.getFactor()));
	}
	
	// Method that returns the width (in x direction) of this object
	public float getWidthX(){
		return widthX;
	}
	
	// Method that returns the width (in z direction) of this object
	public float getWidthZ(){
		return widthZ;
	}
	
	// Method that returns the name of this object
	public String getName(){
		return name;
	}
	
	// Method that returns the rotation angle about the y axis of this object
	public float getAngle(){
		return angleY;
	}
	
	// Method to return this Object as a polygon which can be drawn at its position
	// with specified rotation angle
	public Polygon getPolygon(){
		Point upperLeft  = new Point((int)((posX-widthX/2.0)*1024),(int)((posZ-widthZ/2.0)*1024));
		Point lowerRight = new Point((int)((posX+widthX/2.0)*1024),(int)((posZ+widthZ/2.0)*1024));
		CGRectangle re = new CGRectangle(upperLeft,lowerRight);
		return re.rotateIt(angleY,posX,posZ);	
	}
}
